==> angular-ui-grid-st-1.1.0.tgz: package/src/index.js <==
//Util
import './util/util';

//Libs
import './libs/ui-bootstrap/ui-bootstrap';
import './libs/angular-dynamic-locale/angular-dynamic-locale';
import './libs/angular-idle/angular-idle';
import './libs/bind-html-compile/bind-html-compile';
import './libs/st-dialogs/st-dialogs';
import './libs/ui-grid-drag/ui-grid-drag';
import './libs/ui-select/select';
import './libs/st-dialogs/st-dialogs.css';
import './libs/ui-select/select.css';
import './css/StGrid.css';

//Config
import { ToastrConfig } from './Config/Config.module';
//Constant
import { StGridDefaultsConstant, stGridsConstant } from './Constant/Constant.module';
//Provider
import { StGridConfigProvider } from './Provider/Provider.module';
//Service
import { StGridSetValidators, StGridService } from './Service/Service.module';
//Factory
import { StGridFactory } from './Factory/Factory.module';
//Directive
import { uiGridStActionsDirective, uiGridStDirective, uiSelectStDirective } from './Directive/Directive.module';
//Run
import { Run, TemplateRun } from './Run/Run.module';

angular.module($APP_NAME, ['toastr', 'pascalprecht.translate', 'st.dialogs'])
    .config(ToastrConfig)
    .constant('StGridDefaults', StGridDefaultsConstant)
    .constant('stGrids', stGridsConstant)
    .provider('StGridConfig', StGridConfigProvider)
    .service('StGridSetValidators', StGridSetValidators)
    .service('StGridService', StGridService)
    .factory('StGrid', StGridFactory)
    .directive('uiGridStActions', uiGridStActionsDirective)
    .directive('uiGridSt', uiGridStDirective)
    .directive('uiSelectSt', uiSelectStDirective)
    .run(TemplateRun)
    .run(Run);

==> angular-ui-grid-st-1.1.1.tgz: package/src/index.js <==
//Util
import './util/util';

//Libs
import './libs/ui-bootstrap/ui-bootstrap';
import './libs/angular-dynamic-locale/angular-dynamic-locale';
import './libs/angular-idle/angular-idle';
import './libs/bind-html-compile/bind-html-compile';
import './libs/st-dialogs/st-dialogs';
import './libs/ui-grid-drag/ui-grid-drag';
import './libs/ui-select/select';
import './libs/st-dialogs/st-dialogs.css';
import './libs/ui-select/select.css';
import './css/StGrid.css';

//Config
import { ToastrConfig } from './Config/Config.module';
//Constant
import { StGridDefaultsConstant, stGridsConstant, DictConstant } from './Constant/Constant.module';
//Provider
import { StGridConfigProvider } from './Provider/Provider.module';
//Service
import { StGridSetValidators, StGridService } from './Service/Service.module';
//Factory
import { StGridFactory } from './Factory/Factory.module';
//Directive
import { uiGridStActionsDirective, uiGridStDirective, uiSelectStDirective } from './Directive/Directive.module';
//Run
import { Run, TemplateRun } from './Run/Run.module';

angular.module($APP_NAME, ['toastr', 'pascalprecht.translate', 'st.dialogs'])
    .config(ToastrConfig)
    .constant('StGridDefaults', StGridDefaultsConstant)
    .constant('stGrids', stGridsConstant)
    .constant('stGridDict', DictConstant)
    .provider('StGridConfig', StGridConfigProvider)
    .service('StGridSetValidators', StGridSetValidators)
    .service('StGridService', StGridService)
    .factory('StGrid', StGridFactory)
    .directive('uiGridStActions', uiGridStActionsDirective)
    .directive('uiGridSt', uiGridStDirective)
    .directive('uiSelectSt', uiSelectStDirective)
    .run(TemplateRun)
    .run(Run);
